@@ -7,7 +7,7 @@ from . import basketcase
 def main():
     """Handle command-line script execution."""
 
-    parser = argparse.ArgumentParser(description='Fetch resources from Instagram.')
+    parser = argparse.ArgumentParser(description='Download images and videos from Instagram.')
     parser.add_argument(
         'input_file',
         type=argparse.FileType('r'),
